==> hekate:hqed-m5_6.tar.gz: hqed-m5_6/C/About_ui.h <==
 /**
 * \file	About_ui.h
 * \author	Krzysztof Kaczor kinio4444@gmail.com
 * \date 	28.04.2007 
 * \version	1.0
 * \brief	This file contains class definition that can arrange dialog 'About...'.
 * \note This file is a part of HQEd. It has been develped within the HeKatE Project.
 * HQEd is a free software that you can redistribute and/or modify
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License or 
 * (at your option) any later version.
 * You should have received a copy of the GNU General Public License with HQEd.
 * \note HQEd is distributed in hope that will be useful.
 * It has NO ANY WARRANTY, neither implied warranty of
 * MERCHANTABILITY nor FITNESS FOR A PARTICULAR PURPOSE. 
 * \note Copyright (C) 2006-9 by the HeKatE Project.
 * \see GNU General Public License for more details http://www.gnu.org/licenses/
 * \see HeKatE project http://hekate.ia.agh.edu.pl
 */


#ifndef ABOUT_H
#define ABOUT_H
// -----------------------------------------------------------------------------

#include <QGridLayout>
 
#include "../ui_About.h"
// -----------------------------------------------------------------------------

class GLAboutWidget;
// -----------------------------------------------------------------------------
/**
* \class 	About_ui
* \author	Krzysztof Kaczor kinio4444@gmail.com
* \date 	28.04.2007 
* \brief 	This class contains methods that can arrange dialog 'About...'.
*/
class About_ui : public QWidget, private Ui_About
{
    Q_OBJECT

    GLAboutWidget* glScene;		///< Pointer to OpenGL presentation.
    
    QString fAppVersion;		///< Program version.
    
    QGridLayout* formLayout;	///< Pointer to grid layout form.

public:

     /// \brief Constructor About_ui class.
	///
	/// \param parent Pointer to parent object.
    About_ui(QWidget *parent = 0);
	
	/// \breif Destructor About_ui class.
	~About_ui(void);

	/// \brief Function is triggered when key is pressed.
	///
	/// \param event Pointer to event object.
	/// \return No return value.
    void keyPressEvent(QKeyEvent* event);

	/// \brief Get current application version.
	///
	/// \return QString Information about current application version.
	QString appVersion(void);
};
// -----------------------------------------------------------------------------

extern About_ui* AboutWin;
// -----------------------------------------------------------------------------

#endif

==> hekate:hqed-m6_6.tar.gz: hqed-m6_6/C/About_ui.h <==
 /**
 * \mainpage HQEd
 * \brief HQEd is an application that has been develped within the HeKatE Project.
 * HQEd is a free software that you can redistribute and/or modify
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License or 
 * (at your option) any later version.
 * You should have received a copy of the GNU General Public License with HQEd.
 * \note HQEd is distributed in hope that will be useful.
 * It has NO ANY WARRANTY, neither implied warranty of
 * MERCHANTABILITY nor FITNESS FOR A PARTICULAR PURPOSE. 
 * \author Krzysztof Kaczor kinio4444@gmail.com
 * \date 	28.04.2007 
 * \version	1.15
 * \see GNU General Public License for more details http://www.gnu.org/licenses/
 * \see HeKatE project http://hekate.ia.agh.edu.pl
 * <br /> <center><b>Copyright (C) 2006-9 by the HeKatE Project.</b></center>
 */ 

 /**
 * \file	About_ui.h
 * \author	Krzysztof Kaczor kinio4444@gmail.com
 * \date 	28.04.2007 
 * \version	1.0
 * \brief	This file contains class definition that can arrange dialog 'About...'.
 * \note This file is a part of HQEd. It has been develped within the HeKatE Project.
 * HQEd is a free software that you can redistribute and/or modify
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License or 
 * (at your option) any later version.
 * You should have received a copy of the GNU General Public License with HQEd.
 * \note HQEd is distributed in hope that will be useful.
 * It has NO ANY WARRANTY, neither implied warranty of
 * MERCHANTABILITY nor FITNESS FOR A PARTICULAR PURPOSE. 
 * \note Copyright (C) 2006-9 by the HeKatE Project.
 * \see GNU General Public License for more details http://www.gnu.org/licenses/
 * \see HeKatE project http://hekate.ia.agh.edu.pl
 */


#ifndef ABOUT_H
#define ABOUT_H
// -----------------------------------------------------------------------------

#include <QGridLayout>
 
#include "../ui_About.h"
// -----------------------------------------------------------------------------

class GLAboutWidget;
// -----------------------------------------------------------------------------
/**
* \class 	About_ui
* \author	Krzysztof Kaczor kinio4444@gmail.com
* \date 	28.04.2007 
* \brief 	This class contains methods that can arrange dialog 'About...'.
*/
class About_ui : public QWidget, private Ui_About
{
    Q_OBJECT

    GLAboutWidget* glScene;		///< Pointer to OpenGL presentation.
    
    QString fAppVersion;		///< Program version.
    
    QGridLayout* formLayout;	///< Pointer to grid layout form.

public:

    /// \brief Constructor About_ui class.
	///
	/// \param parent Pointer to parent object.
    About_ui(QWidget *parent = 0);
	
	/// \brief Destructor About_ui class.
	~About_ui(void);

	/// \brief Function is triggered when key is pressed.
	///
	/// \param event Pointer to event object.
	/// \return No return value.
    void keyPressEvent(QKeyEvent* event);

	/// \brief Get current application version.
	///
	/// \return QString Information about current application version.
	QString appVersion(void);
};
// -----------------------------------------------------------------------------

extern About_ui* AboutWin;
// -----------------------------------------------------------------------------

#endif
